/* vi:set ts=8 sts=0 sw=8:
 * $Id: clipboard.h,v 1.5 1999/09/12 03:43:52 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __CLIPBOARD_H__
#define __CLIPBOARD_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include "main.h"
#ifdef USE_CLIPBOARD

#include <gtk/gtk.h>

extern void cut_cb(GtkWidget *widget, gpointer cbdata);
extern void copy_cb(GtkWidget *widget, gpointer cbdata);
extern void paste_cb(GtkWidget *widget, gpointer cbdata);
extern void selall_cb(GtkWidget *widget, gpointer cbdata);

#endif	/* USE_CLIPBOARD */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* __CLIPBOARD_H__ */
